@@ -106,11 +106,19 @@ impl File {
 
     pub fn str(&'static self, row: u32, table: TableIndex, column: u32) -> &'static str {
         let offset = (self.strings + self.u32(row, table, column)) as usize;
-        let last = self.bytes[offset..]
-            .iter()
-            .position(|c| *c == b'\0')
-            .unwrap();
-        std::str::from_utf8(&self.bytes[offset..offset + last]).unwrap()
+
+        // Idealy this would use clib's strlen as its a lot faster, but that dependency adds over a second to the overall build.
+        unsafe {
+            let mut last = 0;
+            for c in &self.bytes[offset..] {
+                if *c == b'\0' {
+                    break;
+                }
+                last += 1;
+            }
+
+            std::str::from_utf8_unchecked(&self.bytes[offset..offset + last])
+        }
     }
 
     pub(crate) fn decode<T: Decode>(&'static self, row: u32, table: TableIndex, column: u32) -> T {
